Prerequisites
-------------

Before you install and configure the Ansible Networking ML2 Driver,
you must configure your OpenStack installation for vlan tenant networking.

#. TODO: Link to or create documentation to show how to do this.
